/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
 *
 * Copyright (C) 2012 Colin Walters <walters@verbum.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author: Colin Walters <walters@verbum.org>
 */

#pragma once

#include <gio/gio.h>
#include "ot-deployment.h"
#include "ot-bootloader.h"
#include "ot-ordered-hash.h"

G_BEGIN_DECLS

gboolean ot_admin_write_deployments (GFile             *sysroot,
                                     int                current_bootversion,
                                     int                new_bootversion,
                                     GPtrArray         *new_deployments,
                                     GCancellable      *cancellable,
                                     GError           **error);

gboolean ot_admin_deploy (GFile             *sysroot,
                          int                current_bootversion,
                          GPtrArray         *current_deployments,
                          const char        *osname,
                          const char        *revision,
                          GKeyFile          *origin,
                          char             **add_kernel_argv,
                          gboolean           retain,
                          OtDeployment      *booted_deployment,
                          OtDeployment      *merge_deployment,
                          OtDeployment     **out_new_deployment,
                          int               *out_new_bootversion,
                          GPtrArray        **out_new_deployments,
                          GCancellable      *cancellable,
                          GError           **error);

G_END_DECLS

